@@ -1,7 +1,7 @@
 package App::dateseq;
 
-our $DATE = '2016-09-28'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2019-05-24'; # DATE
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 use strict;
@@ -201,7 +201,7 @@ sub dateseq {
             }
             $strp->format_datetime($dt);
         };
-        return [200, "OK", $filtered_func, {stream=>1}];
+        return [200, "OK", $filtered_func, {schema=>'str*', stream=>1}];
     }
 }
 
@@ -220,12 +220,16 @@ App::dateseq - Generate a sequence of dates
 
 =head1 VERSION
 
-This document describes version 0.07 of App::dateseq (from Perl distribution App-dateseq), released on 2016-09-28.
+This document describes version 0.08 of App::dateseq (from Perl distribution App-dateseq), released on 2019-05-24.
 
 =head1 FUNCTIONS
 
 
-=head2 dateseq(%args) -> [status, msg, result, meta]
+=head2 dateseq
+
+Usage:
+
+ dateseq(%args) -> [status, msg, payload, meta]
 
 Generate a sequence of dates.
 
@@ -278,7 +282,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -306,7 +310,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2016, 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
